#line 2 "query_l.c"

#line 4 "query_l.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer qry__create_buffer
#define yy_delete_buffer qry__delete_buffer
#define yy_flex_debug qry__flex_debug
#define yy_init_buffer qry__init_buffer
#define yy_flush_buffer qry__flush_buffer
#define yy_load_buffer_state qry__load_buffer_state
#define yy_switch_to_buffer qry__switch_to_buffer
#define yyin qry_in
#define yyleng qry_leng
#define yylex qry_lex
#define yylineno qry_lineno
#define yyout qry_out
#define yyrestart qry_restart
#define yytext qry_text
#define yywrap qry_wrap
#define yyalloc qry_alloc
#define yyrealloc qry_realloc
#define yyfree qry_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE qry_restart(qry_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int qry_leng;

extern FILE *qry_in, *qry_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up qry_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up qry_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via qry_restart()), so that the user can continue scanning by
	 * just pointing qry_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when qry_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int qry_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow qry_wrap()'s to do buffer switches
 * instead of setting up a fresh qry_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void qry_restart (FILE *input_file  );
void qry__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE qry__create_buffer (FILE *file,int size  );
void qry__delete_buffer (YY_BUFFER_STATE b  );
void qry__flush_buffer (YY_BUFFER_STATE b  );
void qry_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void qry_pop_buffer_state (void );

static void qry_ensure_buffer_stack (void );
static void qry__load_buffer_state (void );
static void qry__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER qry__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE qry__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE qry__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE qry__scan_bytes (yyconst char *bytes,int len  );

void *qry_alloc (yy_size_t  );
void *qry_realloc (void *,yy_size_t  );
void qry_free (void *  );

#define yy_new_buffer qry__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        qry_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            qry__create_buffer(qry_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        qry_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            qry__create_buffer(qry_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *qry_in = (FILE *) 0, *qry_out = (FILE *) 0;

typedef int yy_state_type;

extern int qry_lineno;

int qry_lineno = 1;

extern char *qry_text;
#define yytext_ptr qry_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up qry_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	qry_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 62
#define YY_END_OF_BUFFER 63
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[209] =
    {   0,
        0,    0,   63,   62,   61,   60,   59,   62,   62,   62,
       59,   59,   55,   59,   62,   59,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   43,   58,   58,
       58,   58,   62,   52,    0,    1,   50,    0,    2,   56,
       57,   55,   54,   51,   53,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   32,   58,   27,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   58,
        9,   58,   45,   58,   58,   58,   58,   58,   42,   46,
        8,   58,   44,   49,   57,   16,   58,   58,   58,   58,

       58,   58,   58,   58,   22,   31,   58,   58,   58,   58,
       58,   17,   58,   58,   58,   33,   58,   58,   28,   58,
       58,   58,   58,    3,   58,   47,   58,   58,   58,   58,
       58,   58,   58,   13,   39,   58,   58,   58,   58,   19,
       38,   20,   14,   25,   58,   58,   58,   48,   58,    6,
        5,   58,   58,   29,   58,   58,   23,   58,   58,   58,
       40,   58,   58,   58,   58,   58,   10,   58,   34,   37,
       35,   58,   58,   58,   58,   58,   58,   58,   58,   58,
        4,   58,   58,   58,   58,   58,   41,   58,   15,   58,
       58,   26,    7,   36,   58,   24,   58,   18,   58,   58,

       30,   58,   58,   58,   11,   12,   21,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    3,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    7,    8,
        8,    8,    8,    8,    8,    9,    8,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,    1,    3,   11,
       12,   13,    1,    8,   14,   15,   16,   17,   18,   19,
       20,   21,   22,   21,   23,   24,   25,   26,   27,   28,
       21,   29,   30,   31,   32,   33,   21,   34,   35,   21,
        1,    1,    1,    1,   36,    1,   37,   21,   38,   39,

       40,   41,   42,   43,   44,   21,   21,   45,   46,   47,
       21,   48,   21,   49,   50,   51,   52,   53,   21,   21,
       21,   21,    1,   54,    1,    8,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[55] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    1
    } ;

static yyconst flex_int16_t yy_base[212] =
    {   0,
        0,    0,  227,  228,  228,  228,  214,  220,  218,  216,
      228,  212,   46,  209,  208,  207,  189,  190,  189,    0,
      201,  188,   43,  199,   40,   40,   46,  198,   39,   50,
      189,  192,   53,  163,  163,  160,   30,   34,  160,  196,
      152,  157,  148,  228,  196,  228,  228,  193,  228,  189,
      188,   54,  228,  228,  228,    0,  181,  165,  167,  170,
       50,  158,  166,  161,  159,    0,  170,    0,  157,   52,
      163,  155,  154,  160,  168,  148,  153,  148,  149,  148,
      228,  127,    0,  139,   37,  124,  124,  128,    0,    0,
      228,  127,    0,  228,  161,    0,  139,  141,  138,  149,

      144,  147,  146,  140,    0,    0,  138,  131,  129,  124,
      135,    0,  134,  140,  124,    0,  136,  131,    0,  112,
      109,  107,  112,    0,   97,    0,  107,  119,  127,  126,
      114,  112,  112,  104,    0,  117,  107,  119,   64,    0,
        0,  114,    0,    0,  120,   85,  124,    0,   87,    0,
        0,  106,  101,    0,  103,  106,  107,   98,   99,  110,
        0,   96,   94,   92,   96,   68,  228,   74,    0,    0,
      103,  101,   86,   87,   95,   96,   85,   83,   93,   90,
        0,   63,   77,   75,   70,   75,    0,   73,    0,   73,
       62,    0,    0,    0,   75,    0,   66,    0,   65,   67,

        0,   57,   56,   55,    0,    0,    0,  228,  103,  105,
       83
    } ;

static yyconst flex_int16_t yy_def[212] =
    {   0,
      208,    1,  208,  208,  208,  208,  208,  209,  208,  210,
      208,  208,  208,  208,  208,  208,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  208,  208,  209,  208,  208,  210,  208,  208,
      208,  208,  208,  208,  208,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      208,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      208,  211,  211,  208,  208,  211,  211,  211,  211,  211,

      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  208,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,

      211,  211,  211,  211,  211,  211,  211,    0,  208,  208,
      208
    } ;

static yyconst flex_int16_t yy_nxt[283] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   20,   21,   20,
       20,   22,   20,   23,   24,   25,   26,   27,   28,   29,
       30,   20,   31,   20,   32,   20,   33,   34,   20,   20,
       35,   20,   20,   36,   37,   38,   39,   40,   41,   20,
       20,   42,   20,   43,   51,   52,   62,   65,   67,   70,
       74,   81,   51,   52,   63,   68,   66,   76,  108,   86,
       75,   69,   71,   87,  122,   72,   77,   88,   78,   89,
      100,  109,  101,  162,   56,  207,  206,  205,  204,  123,
      203,  202,  201,  200,  199,  198,  197,  196,  195,  163,

      194,  193,   82,   45,   45,   48,   48,  192,  191,  190,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  180,
      179,  178,  177,  176,  175,  174,  173,  172,  171,  170,
      169,  168,  167,  166,  165,  164,  161,  160,  159,  158,
      157,  156,  155,  154,  153,  152,  151,  150,  149,  148,
      147,  146,  145,  144,  143,  142,  141,  140,  139,  138,
      137,  136,  135,  134,  133,  132,  131,  130,  129,  128,
       95,  127,  126,  125,  124,  121,  120,  119,  118,  117,
      116,  115,  114,  113,  112,  111,  110,  107,  106,  105,
      104,  103,  102,   99,   98,   97,   96,   95,   50,   49,

       46,   94,   93,   92,   91,   90,   85,   84,   83,   80,
       79,   73,   64,   61,   60,   59,   58,   57,   55,   54,
       53,   50,   49,   47,   46,   44,  208,    3,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208
    } ;

static yyconst flex_int16_t yy_chk[283] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,   13,   13,   23,   25,   26,   27,
       29,   33,   52,   52,   23,   26,   25,   30,   70,   37,
       29,   26,   27,   37,   85,   27,   30,   38,   30,   38,
       61,   70,   61,  139,  211,  204,  203,  202,  200,   85,
      199,  197,  195,  191,  190,  188,  186,  185,  184,  139,

      183,  182,   33,  209,  209,  210,  210,  180,  179,  178,
      177,  176,  175,  174,  173,  172,  171,  168,  166,  165,
      164,  163,  162,  160,  159,  158,  157,  156,  155,  153,
      152,  149,  147,  146,  145,  142,  138,  137,  136,  134,
      133,  132,  131,  130,  129,  128,  127,  125,  123,  122,
      121,  120,  118,  117,  115,  114,  113,  111,  110,  109,
      108,  107,  104,  103,  102,  101,  100,   99,   98,   97,
       95,   92,   88,   87,   86,   84,   82,   80,   79,   78,
       77,   76,   75,   74,   73,   72,   71,   69,   67,   65,
       64,   63,   62,   60,   59,   58,   57,   51,   50,   48,

       45,   43,   42,   41,   40,   39,   36,   35,   34,   32,
       31,   28,   24,   22,   21,   19,   18,   17,   16,   15,
       14,   12,   10,    9,    8,    7,    3,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int qry__flex_debug;
int qry__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *qry_text;
#line 1 "query_l.l"
#line 2 "query_l.l"
/*
 *                            COPYRIGHT
 *
 *  pcb-rnd, interactive printed circuit board design
 *  Copyright (C) 2016 Tibor 'Igor2' Palinkas
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

/* Query language - compiler: lexical analyzer */

#include "unit.h"
#include "query.h"
#include "query_y.h"
#include "compat_misc.h"
#include "layer.h"

static const char *pcb_qry_program, *pcb_qry_program_ptr;
static int qry_yy_input(char *buf, int buflen);
static pcb_qry_node_t *make_constant(char *str, long val);
#define YY_INPUT(buf, res, buflen) (res = qry_yy_input(buf, buflen))
#line 646 "query_l.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int qry_lex_destroy (void );

int qry_get_debug (void );

void qry_set_debug (int debug_flag  );

YY_EXTRA_TYPE qry_get_extra (void );

void qry_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *qry_get_in (void );

void qry_set_in  (FILE * in_str  );

FILE *qry_get_out (void );

void qry_set_out  (FILE * out_str  );

int qry_get_leng (void );

char *qry_get_text (void );

int qry_get_lineno (void );

void qry_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int qry_wrap (void );
#else
extern int qry_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( qry_text, qry_leng, 1, qry_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( qry_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( qry_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, qry_in))==0 && ferror(qry_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(qry_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int qry_lex (void);

#define YY_DECL int qry_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after qry_text and qry_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 40 "query_l.l"

#line 835 "query_l.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! qry_in )
			qry_in = stdin;

		if ( ! qry_out )
			qry_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			qry_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				qry__create_buffer(qry_in,YY_BUF_SIZE );
		}

		qry__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of qry_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 209 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 228 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 41 "query_l.l"
{ qry_lval.s = pcb_strdup(qry_text+1); qry_lval.s[strlen(qry_lval.s)-1] = '\0'; return T_QSTR; /*"*/ }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 42 "query_l.l"
{ qry_lval.s = pcb_strdup(qry_text+1); qry_lval.s[strlen(qry_lval.s)-1] = '\0'; return T_QSTR; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 44 "query_l.l"
{ return T_LET; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 45 "query_l.l"
{ return T_ASSERT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 46 "query_l.l"
{ return T_RULE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 47 "query_l.l"
{ return T_LIST; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 48 "query_l.l"
{ return T_INVALID; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 49 "query_l.l"
{ return T_FLD_P; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 50 "query_l.l"
{ return T_FLD_A; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 51 "query_l.l"
{ return T_FLD_FLAG; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 53 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_LINE_POINT); return T_CONST; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 54 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_POLY_POINT); return T_CONST; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 55 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_LINE); return T_CONST; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 56 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_TEXT); return T_CONST; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 57 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_POLY); return T_CONST; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 58 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_ARC); return T_CONST; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 59 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_RAT); return T_CONST; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 60 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_PSTK); return T_CONST; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 61 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_PSTK); return T_CONST; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 62 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_SUBC); return T_CONST; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 63 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_SUBC); return T_CONST; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 64 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_NET); return T_CONST; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 65 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_LAYER); return T_CONST; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 66 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_OBJ_LAYERGRP); return T_CONST; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 68 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 1); return T_CONST; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 69 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 1); return T_CONST; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 70 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 1); return T_CONST; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 71 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 1); return T_CONST; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 73 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 0); return T_CONST; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 74 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 0); return T_CONST; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 75 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 0); return T_CONST; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 76 "query_l.l"
{ qry_lval.n = make_constant(qry_text, 0); return T_CONST; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 78 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_TOP); return T_CONST; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 79 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_BOTTOM); return T_CONST; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 80 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_INTERN); return T_CONST; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 81 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_INTERN); return T_CONST; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 82 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_COPPER); return T_CONST; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 83 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_SILK); return T_CONST; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 84 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_MASK); return T_CONST; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 85 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_PASTE); return T_CONST; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 86 "query_l.l"
{ qry_lval.n = make_constant(qry_text, PCB_LYT_OUTLINE); return T_CONST; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 90 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_MM); return T_UNIT; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 91 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_M); return T_UNIT; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 92 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_UM); return T_UNIT; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 93 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_CM); return T_UNIT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 94 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_NM); return T_UNIT; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 95 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_MIL); return T_UNIT; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 96 "query_l.l"
{ qry_lval.u = get_unit_struct_by_allow(PCB_UNIT_ALLOW_IN); return T_UNIT; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 98 "query_l.l"
{ return T_OR; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 99 "query_l.l"
{ return T_AND; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 100 "query_l.l"
{ return T_EQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 101 "query_l.l"
{ return T_NEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 102 "query_l.l"
{ return T_GTEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 103 "query_l.l"
{ return T_LTEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 105 "query_l.l"
{ qry_lval.c = strtol(qry_text, NULL, 10); return T_INT; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 106 "query_l.l"
{ qry_lval.d = strtod(qry_text, NULL); return T_DBL; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 107 "query_l.l"
{ qry_lval.d = strtod(qry_text, NULL); return T_DBL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 108 "query_l.l"
{ qry_lval.s = pcb_strdup(qry_text); return T_STR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 110 "query_l.l"
{ return *qry_text; }
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 112 "query_l.l"
{ return T_NL; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 113 "query_l.l"
{ continue; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 115 "query_l.l"
ECHO;
	YY_BREAK
#line 1231 "query_l.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed qry_in at a new source and called
			 * qry_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = qry_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( qry_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * qry_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of qry_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					qry_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			qry_restart(qry_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) qry_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 209 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 209 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 208);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up qry_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					qry_restart(qry_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( qry_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve qry_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void qry_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        qry_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            qry__create_buffer(qry_in,YY_BUF_SIZE );
	}

	qry__init_buffer(YY_CURRENT_BUFFER,input_file );
	qry__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void qry__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		qry_pop_buffer_state();
	 *		qry_push_buffer_state(new_buffer);
     */
	qry_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	qry__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (qry_wrap()) processing, but the only time this flag
	 * is looked at is after qry_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void qry__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	qry_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE qry__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) qry_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in qry__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) qry_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in qry__create_buffer()" );

	b->yy_is_our_buffer = 1;

	qry__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with qry__create_buffer()
 * 
 */
    void qry__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		qry_free((void *) b->yy_ch_buf  );

	qry_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a qry_restart() or at EOF.
 */
    static void qry__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	qry__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then qry__init_buffer was _probably_
     * called from qry_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void qry__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		qry__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void qry_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	qry_ensure_buffer_stack();

	/* This block is copied from qry__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from qry__switch_to_buffer. */
	qry__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void qry_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	qry__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		qry__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void qry_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)qry_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in qry_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)qry_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in qry_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE qry__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) qry_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in qry__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	qry__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to qry_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       qry__scan_bytes() instead.
 */
YY_BUFFER_STATE qry__scan_string (yyconst char * yystr )
{
    
	return qry__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to qry_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE qry__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) qry_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in qry__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = qry__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in qry__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up qry_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		qry_text[qry_leng] = (yy_hold_char); \
		(yy_c_buf_p) = qry_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		qry_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int qry_get_lineno  (void)
{
        
    return qry_lineno;
}

/** Get the input stream.
 * 
 */
FILE *qry_get_in  (void)
{
        return qry_in;
}

/** Get the output stream.
 * 
 */
FILE *qry_get_out  (void)
{
        return qry_out;
}

/** Get the length of the current token.
 * 
 */
int qry_get_leng  (void)
{
        return qry_leng;
}

/** Get the current token.
 * 
 */

char *qry_get_text  (void)
{
        return qry_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void qry_set_lineno (int  line_number )
{
    
    qry_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see qry__switch_to_buffer
 */
void qry_set_in (FILE *  in_str )
{
        qry_in = in_str ;
}

void qry_set_out (FILE *  out_str )
{
        qry_out = out_str ;
}

int qry_get_debug  (void)
{
        return qry__flex_debug;
}

void qry_set_debug (int  bdebug )
{
        qry__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from qry_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    qry_in = stdin;
    qry_out = stdout;
#else
    qry_in = (FILE *) 0;
    qry_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * qry_lex_init()
     */
    return 0;
}

/* qry_lex_destroy is for both reentrant and non-reentrant scanners. */
int qry_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		qry__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		qry_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	qry_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * qry_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *qry_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *qry_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void qry_free (void * ptr )
{
	free( (char *) ptr );	/* see qry_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 115 "query_l.l"



static int qry_yy_input(char *buf, int buflen)
{
	int len;
	for(len = 0; (*pcb_qry_program_ptr != '\0') && (buflen > 0); len++,buflen--) {
/*		printf("IN: '%c'\n",  *pcb_qry_program_ptr);*/
		*buf = *pcb_qry_program_ptr;
		buf++;
		pcb_qry_program_ptr++;
	}
	return len;
}

void pcb_qry_set_input(const char *script)
{
	pcb_qry_program = pcb_qry_program_ptr = script;
}

static pcb_qry_node_t *make_constant(char *str, long val)
{
	pcb_qry_node_t *res = pcb_qry_n_alloc(PCBQ_DATA_CONST);
	res->data.str = pcb_strdup(str);
	res->precomp.cnst = val;
	return res;
}

